@@ -6,6 +6,8 @@ from ...utils import Utils
 
 
 class AuthenticationClient(BaseClient):
+    """用户信息验证客户端"""
+
     def __init__(self, config):
         super().__init__(config)
 
@@ -80,7 +82,7 @@ class AuthenticationClient(BaseClient):
         )
 
     def user_exempted_info(self, request: UserExemptedInfoRequest):
-        """ 上传免验证用户名单信息
+        """ 上传非居民身份证验证名单信息
 
         :type request: UserExemptedInfoRequest
         :param request: the UserExemptedInfoRequest request parameters class.
@@ -94,7 +96,7 @@ class AuthenticationClient(BaseClient):
         )
 
     def user_white_check(self, request: UserWhiteCheckRequest):
-        """ 查看免验证用户名单是否存在
+        """ 查看用户是否在非居民身份证验证名单中
 
         :type request: UserWhiteCheckRequest
         :param request: the UserWhiteCheckRequest request parameters class.
