@@ -5,7 +5,7 @@ from ...base import BaseRequest
 
 class ApiUseSignContractRequest(BaseRequest):
     """
-    获取协议预览 URL 请求
+    获取协议预览 URL 请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -15,8 +15,8 @@ class ApiUseSignContractRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None
+        dealer_id = None,
+        broker_id = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -25,7 +25,7 @@ class ApiUseSignContractRequest(BaseRequest):
 
 class ApiUseSignContractResponse(BaseRequest):
     """
-    获取协议预览 URL 返回
+    获取协议预览 URL 返回-响应
 
     :type url: string
     :param url: 预览跳转 URL
@@ -35,8 +35,8 @@ class ApiUseSignContractResponse(BaseRequest):
     """
     def __init__(
         self,
-        url=None,
-        title=None
+        url = None,
+        title = None
     ):
         super().__init__()
         self.url = url
@@ -45,7 +45,7 @@ class ApiUseSignContractResponse(BaseRequest):
 
 class ApiUserSignContractRequest(BaseRequest):
     """
-    获取协议预览 URL 请求 V2
+    获取协议预览 URL 请求 V2-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -55,8 +55,8 @@ class ApiUserSignContractRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None
+        dealer_id = None,
+        broker_id = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -65,7 +65,7 @@ class ApiUserSignContractRequest(BaseRequest):
 
 class ApiUserSignContractResponse(BaseRequest):
     """
-    获取协议预览 URL 返回 V2
+    获取协议预览 URL 返回 V2-响应
 
     :type url: string
     :param url: 预览跳转 URL
@@ -75,8 +75,8 @@ class ApiUserSignContractResponse(BaseRequest):
     """
     def __init__(
         self,
-        url=None,
-        title=None
+        url = None,
+        title = None
     ):
         super().__init__()
         self.url = url
@@ -85,7 +85,7 @@ class ApiUserSignContractResponse(BaseRequest):
 
 class ApiUserSignRequest(BaseRequest):
     """
-    用户签约请求
+    用户签约请求-请求
 
     :type broker_id: string
     :param broker_id: 综合服务主体 ID
@@ -104,11 +104,11 @@ class ApiUserSignRequest(BaseRequest):
     """
     def __init__(
         self,
-        broker_id=None,
-        dealer_id=None,
-        real_name=None,
-        id_card=None,
-        card_type=None
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        id_card = None,
+        card_type = None
     ):
         super().__init__()
         self.broker_id = broker_id
@@ -120,14 +120,14 @@ class ApiUserSignRequest(BaseRequest):
 
 class ApiUserSignResponse(BaseRequest):
     """
-    用户签约返回
+    用户签约返回-响应
 
     :type status: string
     :param status: 是否签约成功
     """
     def __init__(
         self,
-        status=None
+        status = None
     ):
         super().__init__()
         self.status = status
@@ -135,7 +135,7 @@ class ApiUserSignResponse(BaseRequest):
 
 class GetApiUserSignStatusRequest(BaseRequest):
     """
-    获取用户签约状态请求
+    获取用户签约状态请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -151,10 +151,10 @@ class GetApiUserSignStatusRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        id_card=None
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        id_card = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -165,7 +165,7 @@ class GetApiUserSignStatusRequest(BaseRequest):
 
 class GetApiUserSignStatusResponse(BaseRequest):
     """
-    获取用户签约状态返回
+    获取用户签约状态返回-响应
 
     :type signed_at: string
     :param signed_at: 签约时间
@@ -175,8 +175,8 @@ class GetApiUserSignStatusResponse(BaseRequest):
     """
     def __init__(
         self,
-        signed_at=None,
-        status=None
+        signed_at = None,
+        status = None
     ):
         super().__init__()
         self.signed_at = signed_at
@@ -185,7 +185,7 @@ class GetApiUserSignStatusResponse(BaseRequest):
 
 class ApiUserSignReleaseRequest(BaseRequest):
     """
-    用户解约（测试账号专用接口）请求
+    用户解约（测试账号专用接口）请求-请求
 
     :type broker_id: string
     :param broker_id: 综合服务主体 ID
@@ -204,11 +204,11 @@ class ApiUserSignReleaseRequest(BaseRequest):
     """
     def __init__(
         self,
-        broker_id=None,
-        dealer_id=None,
-        real_name=None,
-        id_card=None,
-        card_type=None
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        id_card = None,
+        card_type = None
     ):
         super().__init__()
         self.broker_id = broker_id
@@ -220,14 +220,14 @@ class ApiUserSignReleaseRequest(BaseRequest):
 
 class ApiUserSignReleaseResponse(BaseRequest):
     """
-    用户解约（测试账号专用接口）返回
+    用户解约（测试账号专用接口）返回-响应
 
     :type status: string
     :param status: 是否解约成功
     """
     def __init__(
         self,
-        status=None
+        status = None
     ):
         super().__init__()
         self.status = status
