@@ -5,7 +5,7 @@ from ...base import BaseRequest
 
 class BankCardFourAuthVerifyRequest(BaseRequest):
     """
-    银行卡四要素鉴权请求（下发短信验证码）请求
+    银行卡四要素鉴权请求（下发短信验证码）请求-请求
 
     :type card_no: string
     :param card_no: 银行卡号
@@ -21,10 +21,10 @@ class BankCardFourAuthVerifyRequest(BaseRequest):
     """
     def __init__(
         self,
-        card_no=None,
-        id_card=None,
-        real_name=None,
-        mobile=None
+        card_no = None,
+        id_card = None,
+        real_name = None,
+        mobile = None
     ):
         super().__init__()
         self.card_no = card_no
@@ -35,14 +35,14 @@ class BankCardFourAuthVerifyRequest(BaseRequest):
 
 class BankCardFourAuthVerifyResponse(BaseRequest):
     """
-    银行卡四要素鉴权请求（下发短信验证码）返回
+    银行卡四要素鉴权请求（下发短信验证码）返回-响应
 
     :type ref: string
     :param ref: 交易凭证
     """
     def __init__(
         self,
-        ref=None
+        ref = None
     ):
         super().__init__()
         self.ref = ref
@@ -50,7 +50,7 @@ class BankCardFourAuthVerifyResponse(BaseRequest):
 
 class BankCardFourAuthConfirmRequest(BaseRequest):
     """
-    银行卡四要素确认请求（上传短信验证码）请求
+    银行卡四要素确认请求（上传短信验证码）请求-请求
 
     :type card_no: string
     :param card_no: 银行卡号
@@ -72,12 +72,12 @@ class BankCardFourAuthConfirmRequest(BaseRequest):
     """
     def __init__(
         self,
-        card_no=None,
-        id_card=None,
-        real_name=None,
-        mobile=None,
-        captcha=None,
-        ref=None
+        card_no = None,
+        id_card = None,
+        real_name = None,
+        mobile = None,
+        captcha = None,
+        ref = None
     ):
         super().__init__()
         self.card_no = card_no
@@ -90,13 +90,13 @@ class BankCardFourAuthConfirmRequest(BaseRequest):
 
 class BankCardFourAuthConfirmResponse(BaseRequest):
     """
-    银行卡四要素确认请求（上传短信验证码）返回
+    银行卡四要素确认请求（上传短信验证码）返回-响应
     """
 
 
 class BankCardFourVerifyRequest(BaseRequest):
     """
-    银行卡四要素验证请求
+    银行卡四要素验证请求-请求
 
     :type card_no: string
     :param card_no: 银行卡号
@@ -112,10 +112,10 @@ class BankCardFourVerifyRequest(BaseRequest):
     """
     def __init__(
         self,
-        card_no=None,
-        id_card=None,
-        real_name=None,
-        mobile=None
+        card_no = None,
+        id_card = None,
+        real_name = None,
+        mobile = None
     ):
         super().__init__()
         self.card_no = card_no
@@ -126,13 +126,13 @@ class BankCardFourVerifyRequest(BaseRequest):
 
 class BankCardFourVerifyResponse(BaseRequest):
     """
-    银行卡四要素验证返回
+    银行卡四要素验证返回-响应
     """
 
 
 class BankCardThreeVerifyRequest(BaseRequest):
     """
-    银行卡三要素验证请求
+    银行卡三要素验证请求-请求
 
     :type card_no: string
     :param card_no: 银行卡号
@@ -145,9 +145,9 @@ class BankCardThreeVerifyRequest(BaseRequest):
     """
     def __init__(
         self,
-        card_no=None,
-        id_card=None,
-        real_name=None
+        card_no = None,
+        id_card = None,
+        real_name = None
     ):
         super().__init__()
         self.card_no = card_no
@@ -157,13 +157,13 @@ class BankCardThreeVerifyRequest(BaseRequest):
 
 class BankCardThreeVerifyResponse(BaseRequest):
     """
-    银行卡三要素验证返回
+    银行卡三要素验证返回-响应
     """
 
 
 class IDCardVerifyRequest(BaseRequest):
     """
-    身份证实名验证请求
+    身份证实名验证请求-请求
 
     :type id_card: string
     :param id_card: 身份证号码
@@ -173,8 +173,8 @@ class IDCardVerifyRequest(BaseRequest):
     """
     def __init__(
         self,
-        id_card=None,
-        real_name=None
+        id_card = None,
+        real_name = None
     ):
         super().__init__()
         self.id_card = id_card
@@ -183,13 +183,13 @@ class IDCardVerifyRequest(BaseRequest):
 
 class IDCardVerifyResponse(BaseRequest):
     """
-    身份证实名验证返回
+    身份证实名验证返回-响应
     """
 
 
 class UserExemptedInfoRequest(BaseRequest):
     """
-    上传免验证用户名单信息请求
+    上传非居民身份证验证名单信息请求-请求
 
     :type card_type: string
     :param card_type: 证件类型码
@@ -226,21 +226,25 @@ class UserExemptedInfoRequest(BaseRequest):
 
     :type ref: string
     :param ref: 请求流水号
+
+    :type image_urls: list
+    :param image_urls: 证件照片 URL 地址
     """
     def __init__(
         self,
-        card_type=None,
-        id_card=None,
-        real_name=None,
-        comment_apply=None,
-        broker_id=None,
-        dealer_id=None,
-        user_images=None,
-        country=None,
-        birthday=None,
-        gender=None,
-        notify_url=None,
-        ref=None
+        card_type = None,
+        id_card = None,
+        real_name = None,
+        comment_apply = None,
+        broker_id = None,
+        dealer_id = None,
+        user_images = None,
+        country = None,
+        birthday = None,
+        gender = None,
+        notify_url = None,
+        ref = None,
+        image_urls = None
     ):
         super().__init__()
         self.card_type = card_type
@@ -255,18 +259,19 @@ class UserExemptedInfoRequest(BaseRequest):
         self.gender = gender
         self.notify_url = notify_url
         self.ref = ref
+        self.image_urls = image_urls
 
 
 class UserExemptedInfoResponse(BaseRequest):
     """
-    上传免验证用户名单信息返回
+    上传非居民身份证验证名单信息返回-响应
 
     :type ok: string
     :param ok: 是否上传成功
     """
     def __init__(
         self,
-        ok=None
+        ok = None
     ):
         super().__init__()
         self.ok = ok
@@ -274,7 +279,7 @@ class UserExemptedInfoResponse(BaseRequest):
 
 class NotifyUserExemptedInfoRequest(BaseRequest):
     """
-    上传免验证用户名单信息审核结果通知
+    非居民身份证验证名单审核结果回调通知-请求
 
     :type broker_id: string
     :param broker_id: 综合服务主体 ID
@@ -299,13 +304,13 @@ class NotifyUserExemptedInfoRequest(BaseRequest):
     """
     def __init__(
         self,
-        broker_id=None,
-        dealer_id=None,
-        real_name=None,
-        id_card=None,
-        status=None,
-        ref=None,
-        comment=None
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        id_card = None,
+        status = None,
+        ref = None,
+        comment = None
     ):
         super().__init__()
         self.broker_id = broker_id
@@ -319,7 +324,7 @@ class NotifyUserExemptedInfoRequest(BaseRequest):
 
 class UserWhiteCheckRequest(BaseRequest):
     """
-    查看免验证用户名单是否存在请求
+    查看用户是否在非居民身份证验证名单中请求-请求
 
     :type id_card: string
     :param id_card: 证件号码
@@ -329,8 +334,8 @@ class UserWhiteCheckRequest(BaseRequest):
     """
     def __init__(
         self,
-        id_card=None,
-        real_name=None
+        id_card = None,
+        real_name = None
     ):
         super().__init__()
         self.id_card = id_card
@@ -339,14 +344,14 @@ class UserWhiteCheckRequest(BaseRequest):
 
 class UserWhiteCheckResponse(BaseRequest):
     """
-    查看免验证用户名单是否存在返回
+    查看用户是否在非居民身份证验证名单中返回-响应
 
     :type ok: bool
     :param ok: 
     """
     def __init__(
         self,
-        ok=None
+        ok = None
     ):
         super().__init__()
         self.ok = ok
@@ -354,7 +359,7 @@ class UserWhiteCheckResponse(BaseRequest):
 
 class GetBankCardInfoRequest(BaseRequest):
     """
-    银行卡信息查询请求
+    银行卡信息查询请求-请求
 
     :type card_no: string
     :param card_no: 银行卡号
@@ -364,8 +369,8 @@ class GetBankCardInfoRequest(BaseRequest):
     """
     def __init__(
         self,
-        card_no=None,
-        bank_name=None
+        card_no = None,
+        bank_name = None
     ):
         super().__init__()
         self.card_no = card_no
@@ -374,7 +379,7 @@ class GetBankCardInfoRequest(BaseRequest):
 
 class GetBankCardInfoResponse(BaseRequest):
     """
-    银行卡信息查询返回
+    银行卡信息查询返回-响应
 
     :type bank_code: string
     :param bank_code: 银行代码
@@ -390,10 +395,10 @@ class GetBankCardInfoResponse(BaseRequest):
     """
     def __init__(
         self,
-        bank_code=None,
-        bank_name=None,
-        card_type=None,
-        is_support=None
+        bank_code = None,
+        bank_name = None,
+        card_type = None,
+        is_support = None
     ):
         super().__init__()
         self.bank_code = bank_code
