@@ -5,7 +5,7 @@ from ...base import BaseRequest
 
 class H5GetStartUrlRequest(BaseRequest):
     """
-    预启动请求
+    预启动请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -33,14 +33,14 @@ class H5GetStartUrlRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None,
-        dealer_user_id=None,
-        client_type=None,
-        notify_url=None,
-        color=None,
-        return_url=None,
-        customer_title=None
+        dealer_id = None,
+        broker_id = None,
+        dealer_user_id = None,
+        client_type = None,
+        notify_url = None,
+        color = None,
+        return_url = None,
+        customer_title = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -55,14 +55,14 @@ class H5GetStartUrlRequest(BaseRequest):
 
 class H5GetStartUrlResponse(BaseRequest):
     """
-    预启动返回
+    预启动返回-响应
 
     :type h5_url: string
     :param h5_url: 跳转 URL
     """
     def __init__(
         self,
-        h5_url=None
+        h5_url = None
     ):
         super().__init__()
         self.h5_url = h5_url
@@ -70,7 +70,7 @@ class H5GetStartUrlResponse(BaseRequest):
 
 class H5EcoCityAicStatusRequest(BaseRequest):
     """
-    查询个体工商户状态请求
+    查询个体工商户状态请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -92,12 +92,12 @@ class H5EcoCityAicStatusRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None,
-        dealer_user_id=None,
-        id_card=None,
-        real_name=None,
-        open_id=None
+        dealer_id = None,
+        broker_id = None,
+        dealer_user_id = None,
+        id_card = None,
+        real_name = None,
+        open_id = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -110,7 +110,7 @@ class H5EcoCityAicStatusRequest(BaseRequest):
 
 class H5EcoCityAicStatusResponse(BaseRequest):
     """
-    查询个体工商户状态返回
+    查询个体工商户状态返回-响应
 
     :type status: int
     :param status: 用户签约状态
@@ -141,15 +141,15 @@ class H5EcoCityAicStatusResponse(BaseRequest):
     """
     def __init__(
         self,
-        status=None,
-        status_message=None,
-        status_detail=None,
-        status_detail_message=None,
-        applyed_at=None,
-        registed_at=None,
-        uscc=None,
-        id_card=None,
-        real_name=None
+        status = None,
+        status_message = None,
+        status_detail = None,
+        status_detail_message = None,
+        applyed_at = None,
+        registed_at = None,
+        uscc = None,
+        id_card = None,
+        real_name = None
     ):
         super().__init__()
         self.status = status
@@ -165,7 +165,7 @@ class H5EcoCityAicStatusResponse(BaseRequest):
 
 class NotifyH5EcoCityAicRequest(BaseRequest):
     """
-    结果回调
+    结果回调-请求
 
     :type open_id: string
     :param open_id: 用户唯一标识
@@ -211,20 +211,20 @@ class NotifyH5EcoCityAicRequest(BaseRequest):
     """
     def __init__(
         self,
-        open_id=None,
-        dealer_user_id=None,
-        submit_at=None,
-        registed_at=None,
-        status=None,
-        status_message=None,
-        status_detail=None,
-        status_detail_message=None,
-        dealer_id=None,
-        broker_id=None,
-        uscc=None,
-        id_card=None,
-        real_name=None,
-        type=None
+        open_id = None,
+        dealer_user_id = None,
+        submit_at = None,
+        registed_at = None,
+        status = None,
+        status_message = None,
+        status_detail = None,
+        status_detail_message = None,
+        dealer_id = None,
+        broker_id = None,
+        uscc = None,
+        id_card = None,
+        real_name = None,
+        type = None
     ):
         super().__init__()
         self.open_id = open_id
