@@ -5,7 +5,7 @@ from ...base import BaseRequest
 
 class H5UserPresignRequest(BaseRequest):
     """
-    预申请签约请求
+    预申请签约请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -21,14 +21,18 @@ class H5UserPresignRequest(BaseRequest):
 
     :type certificate_type: int
     :param certificate_type: 证件类型 0：身份证 2：港澳居民来往内地通行证 3：护照 5：台湾居民来往大陆通行证 9：港澳居民居住证 10：台湾居民居住证 11：外国人永久居留身份证 12：外国人工作许可证
+
+    :type collect_phone_no: int
+    :param collect_phone_no: 是否收集手机号码 0：不收集（默认） 1：收集手机号码
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        id_card=None,
-        certificate_type=None
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        id_card = None,
+        certificate_type = None,
+        collect_phone_no = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -36,11 +40,12 @@ class H5UserPresignRequest(BaseRequest):
         self.real_name = real_name
         self.id_card = id_card
         self.certificate_type = certificate_type
+        self.collect_phone_no = collect_phone_no
 
 
 class H5UserPresignResponse(BaseRequest):
     """
-    预申请签约返回
+    预申请签约返回-响应
 
     :type uid: string
     :param uid: 用户 ID（废弃字段）
@@ -53,9 +58,9 @@ class H5UserPresignResponse(BaseRequest):
     """
     def __init__(
         self,
-        uid=None,
-        token=None,
-        status=None
+        uid = None,
+        token = None,
+        status = None
     ):
         super().__init__()
         self.uid = uid
@@ -65,7 +70,7 @@ class H5UserPresignResponse(BaseRequest):
 
 class H5UserSignRequest(BaseRequest):
     """
-    申请签约请求
+    申请签约请求-请求
 
     :type token: string
     :param token: H5 签约 token
@@ -81,10 +86,10 @@ class H5UserSignRequest(BaseRequest):
     """
     def __init__(
         self,
-        token=None,
-        color=None,
-        url=None,
-        redirect_url=None
+        token = None,
+        color = None,
+        url = None,
+        redirect_url = None
     ):
         super().__init__()
         self.token = token
@@ -95,14 +100,14 @@ class H5UserSignRequest(BaseRequest):
 
 class H5UserSignResponse(BaseRequest):
     """
-    申请签约返回
+    申请签约返回-响应
 
     :type url: string
     :param url: H5 签约页面 URL
     """
     def __init__(
         self,
-        url=None
+        url = None
     ):
         super().__init__()
         self.url = url
@@ -110,7 +115,7 @@ class H5UserSignResponse(BaseRequest):
 
 class GetH5UserSignStatusRequest(BaseRequest):
     """
-    获取用户签约状态请求
+    获取用户签约状态请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -126,10 +131,10 @@ class GetH5UserSignStatusRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        id_card=None
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        id_card = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -140,7 +145,7 @@ class GetH5UserSignStatusRequest(BaseRequest):
 
 class GetH5UserSignStatusResponse(BaseRequest):
     """
-    获取用户签约状态返回
+    获取用户签约状态返回-响应
 
     :type signed_at: string
     :param signed_at: 签约时间
@@ -150,8 +155,8 @@ class GetH5UserSignStatusResponse(BaseRequest):
     """
     def __init__(
         self,
-        signed_at=None,
-        status=None
+        signed_at = None,
+        status = None
     ):
         super().__init__()
         self.signed_at = signed_at
@@ -160,7 +165,7 @@ class GetH5UserSignStatusResponse(BaseRequest):
 
 class H5UserReleaseRequest(BaseRequest):
     """
-    用户解约（测试账号专用接口）请求
+    用户解约（测试账号专用接口）请求-请求
 
     :type broker_id: string
     :param broker_id: 综合服务主体 ID
@@ -179,11 +184,11 @@ class H5UserReleaseRequest(BaseRequest):
     """
     def __init__(
         self,
-        broker_id=None,
-        dealer_id=None,
-        real_name=None,
-        id_card=None,
-        certificate_type=None
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        id_card = None,
+        certificate_type = None
     ):
         super().__init__()
         self.broker_id = broker_id
@@ -195,14 +200,14 @@ class H5UserReleaseRequest(BaseRequest):
 
 class H5UserReleaseResponse(BaseRequest):
     """
-    用户解约（测试账号专用接口）返回
+    用户解约（测试账号专用接口）返回-响应
 
     :type status: string
     :param status: 是否解约成功
     """
     def __init__(
         self,
-        status=None
+        status = None
     ):
         super().__init__()
         self.status = status
@@ -210,7 +215,7 @@ class H5UserReleaseResponse(BaseRequest):
 
 class NotifyH5UserSignRequest(BaseRequest):
     """
-    签约回调
+    签约回调-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -229,11 +234,11 @@ class NotifyH5UserSignRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        id_card=None,
-        phone=None
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        id_card = None,
+        phone = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
