@@ -5,7 +5,7 @@ from ...base import BaseRequest
 
 class CreateBankpayOrderRequest(BaseRequest):
     """
-    银行卡实时支付请求
+    银行卡实时支付请求-请求
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -42,17 +42,17 @@ class CreateBankpayOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        card_no=None,
-        id_card=None,
-        phone_no=None,
-        pay=None,
-        pay_remark=None,
-        notify_url=None,
-        project_id=None
+        order_id = None,
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        card_no = None,
+        id_card = None,
+        phone_no = None,
+        pay = None,
+        pay_remark = None,
+        notify_url = None,
+        project_id = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -70,10 +70,10 @@ class CreateBankpayOrderRequest(BaseRequest):
 
 class CreateBankpayOrderResponse(BaseRequest):
     """
-    银行卡实时支付返回
+    银行卡实时支付返回-响应
 
     :type order_id: string
-    :param order_id: 
+    :param order_id: 平台企业订单号
 
     :type ref: string
     :param ref: 综合服务平台流水号
@@ -83,9 +83,9 @@ class CreateBankpayOrderResponse(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        ref=None,
-        pay=None
+        order_id = None,
+        ref = None,
+        pay = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -95,7 +95,7 @@ class CreateBankpayOrderResponse(BaseRequest):
 
 class CreateAlipayOrderRequest(BaseRequest):
     """
-    支付宝实时支付请求
+    支付宝实时支付请求-请求
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -135,18 +135,18 @@ class CreateAlipayOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        card_no=None,
-        id_card=None,
-        phone_no=None,
-        pay=None,
-        pay_remark=None,
-        notify_url=None,
-        project_id=None,
-        check_name=None
+        order_id = None,
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        card_no = None,
+        id_card = None,
+        phone_no = None,
+        pay = None,
+        pay_remark = None,
+        notify_url = None,
+        project_id = None,
+        check_name = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -165,7 +165,7 @@ class CreateAlipayOrderRequest(BaseRequest):
 
 class CreateAlipayOrderResponse(BaseRequest):
     """
-    支付宝实时支付返回
+    支付宝实时支付返回-响应
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -178,9 +178,9 @@ class CreateAlipayOrderResponse(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        ref=None,
-        pay=None
+        order_id = None,
+        ref = None,
+        pay = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -190,7 +190,7 @@ class CreateAlipayOrderResponse(BaseRequest):
 
 class CreateWxpayOrderRequest(BaseRequest):
     """
-    微信实时支付请求
+    微信实时支付请求-请求
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -236,20 +236,20 @@ class CreateWxpayOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        dealer_id=None,
-        broker_id=None,
-        real_name=None,
-        openid=None,
-        id_card=None,
-        phone_no=None,
-        pay=None,
-        pay_remark=None,
-        notify_url=None,
-        wx_app_id=None,
-        wxpay_mode=None,
-        project_id=None,
-        notes=None
+        order_id = None,
+        dealer_id = None,
+        broker_id = None,
+        real_name = None,
+        openid = None,
+        id_card = None,
+        phone_no = None,
+        pay = None,
+        pay_remark = None,
+        notify_url = None,
+        wx_app_id = None,
+        wxpay_mode = None,
+        project_id = None,
+        notes = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -270,7 +270,7 @@ class CreateWxpayOrderRequest(BaseRequest):
 
 class CreateWxpayOrderResponse(BaseRequest):
     """
-    微信实时支付返回
+    微信实时支付返回-响应
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -283,9 +283,9 @@ class CreateWxpayOrderResponse(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        ref=None,
-        pay=None
+        order_id = None,
+        ref = None,
+        pay = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -295,7 +295,7 @@ class CreateWxpayOrderResponse(BaseRequest):
 
 class GetOrderRequest(BaseRequest):
     """
-    查询单笔订单信息请求
+    查询单笔订单信息请求-请求
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -308,9 +308,9 @@ class GetOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        channel=None,
-        data_type=None
+        order_id = None,
+        channel = None,
+        data_type = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -320,7 +320,7 @@ class GetOrderRequest(BaseRequest):
 
 class GetOrderResponse(BaseRequest):
     """
-    查询单笔订单信息返回
+    查询单笔订单信息返回-响应
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -358,6 +358,9 @@ class GetOrderResponse(BaseRequest):
     :type status_detail_message: string
     :param status_detail_message: 订单详细状态码描述
 
+    :type supplemental_detail_message: string
+    :param supplemental_detail_message: 订单状态补充信息
+
     :type broker_amount: string
     :param broker_amount: 综合服务主体支付金额
 
@@ -377,20 +380,32 @@ class GetOrderResponse(BaseRequest):
     :param finished_time: 订单完成时间，精确到秒
 
     :type broker_fee: string
-    :param broker_fee: 综合服务主体加成服务费
+    :param broker_fee: 应收综合服务主体加成服务费金额
 
     :type broker_real_fee: string
-    :param broker_real_fee: 余额账户支出加成服务费
+    :param broker_real_fee: 应收余额账户支出加成服务费金额
 
     :type broker_deduct_fee: string
-    :param broker_deduct_fee: 抵扣账户支出加成服务费
+    :param broker_deduct_fee: 应收加成服务费抵扣金额
+
+    :type user_fee: string
+    :param user_fee: 应收用户加成服务费金额
+
+    :type received_broker_fee: string
+    :param received_broker_fee: 实收综合服务主体加成服务费金额
+
+    :type received_broker_real_fee: string
+    :param received_broker_real_fee: 实收余额账户支出加成服务费金额
+
+    :type received_broker_deduct_fee: string
+    :param received_broker_deduct_fee: 实收加成服务费抵扣金额
+
+    :type received_user_fee: string
+    :param received_user_fee: 实收用户加成服务费金额
 
     :type pay_remark: string
     :param pay_remark: 订单备注
 
-    :type user_fee: string
-    :param user_fee: 用户加成服务费
-
     :type bank_name: string
     :param bank_name: 银行名称
 
@@ -414,36 +429,41 @@ class GetOrderResponse(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        pay=None,
-        broker_id=None,
-        dealer_id=None,
-        real_name=None,
-        card_no=None,
-        id_card=None,
-        phone_no=None,
-        status=None,
-        status_detail=None,
-        status_message=None,
-        status_detail_message=None,
-        broker_amount=None,
-        ref=None,
-        broker_bank_bill=None,
-        withdraw_platform=None,
-        created_at=None,
-        finished_time=None,
-        broker_fee=None,
-        broker_real_fee=None,
-        broker_deduct_fee=None,
-        pay_remark=None,
-        user_fee=None,
-        bank_name=None,
-        project_id=None,
-        anchor_id=None,
-        notes=None,
-        sys_amount=None,
-        tax=None,
-        sys_fee=None
+        order_id = None,
+        pay = None,
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        card_no = None,
+        id_card = None,
+        phone_no = None,
+        status = None,
+        status_detail = None,
+        status_message = None,
+        status_detail_message = None,
+        supplemental_detail_message = None,
+        broker_amount = None,
+        ref = None,
+        broker_bank_bill = None,
+        withdraw_platform = None,
+        created_at = None,
+        finished_time = None,
+        broker_fee = None,
+        broker_real_fee = None,
+        broker_deduct_fee = None,
+        user_fee = None,
+        received_broker_fee = None,
+        received_broker_real_fee = None,
+        received_broker_deduct_fee = None,
+        received_user_fee = None,
+        pay_remark = None,
+        bank_name = None,
+        project_id = None,
+        anchor_id = None,
+        notes = None,
+        sys_amount = None,
+        tax = None,
+        sys_fee = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -458,6 +478,7 @@ class GetOrderResponse(BaseRequest):
         self.status_detail = status_detail
         self.status_message = status_message
         self.status_detail_message = status_detail_message
+        self.supplemental_detail_message = supplemental_detail_message
         self.broker_amount = broker_amount
         self.ref = ref
         self.broker_bank_bill = broker_bank_bill
@@ -467,8 +488,12 @@ class GetOrderResponse(BaseRequest):
         self.broker_fee = broker_fee
         self.broker_real_fee = broker_real_fee
         self.broker_deduct_fee = broker_deduct_fee
-        self.pay_remark = pay_remark
         self.user_fee = user_fee
+        self.received_broker_fee = received_broker_fee
+        self.received_broker_real_fee = received_broker_real_fee
+        self.received_broker_deduct_fee = received_broker_deduct_fee
+        self.received_user_fee = received_user_fee
+        self.pay_remark = pay_remark
         self.bank_name = bank_name
         self.project_id = project_id
         self.anchor_id = anchor_id
@@ -480,7 +505,7 @@ class GetOrderResponse(BaseRequest):
 
 class GetDealerVARechargeAccountRequest(BaseRequest):
     """
-    查询平台企业汇款信息请求
+    查询平台企业汇款信息请求-请求
 
     :type broker_id: string
     :param broker_id: 综合服务主体 ID
@@ -490,8 +515,8 @@ class GetDealerVARechargeAccountRequest(BaseRequest):
     """
     def __init__(
         self,
-        broker_id=None,
-        dealer_id=None
+        broker_id = None,
+        dealer_id = None
     ):
         super().__init__()
         self.broker_id = broker_id
@@ -500,7 +525,7 @@ class GetDealerVARechargeAccountRequest(BaseRequest):
 
 class GetDealerVARechargeAccountResponse(BaseRequest):
     """
-    查询平台企业汇款信息返回
+    查询平台企业汇款信息返回-响应
 
     :type acct_name: string
     :param acct_name: 账户名称
@@ -516,10 +541,10 @@ class GetDealerVARechargeAccountResponse(BaseRequest):
     """
     def __init__(
         self,
-        acct_name=None,
-        acct_no=None,
-        bank_name=None,
-        dealer_acct_name=None
+        acct_name = None,
+        acct_no = None,
+        bank_name = None,
+        dealer_acct_name = None
     ):
         super().__init__()
         self.acct_name = acct_name
@@ -530,7 +555,7 @@ class GetDealerVARechargeAccountResponse(BaseRequest):
 
 class CancelOrderRequest(BaseRequest):
     """
-    取消待支付订单请求
+    取消待支付订单请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -546,10 +571,10 @@ class CancelOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        order_id=None,
-        ref=None,
-        channel=None
+        dealer_id = None,
+        order_id = None,
+        ref = None,
+        channel = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -560,14 +585,59 @@ class CancelOrderRequest(BaseRequest):
 
 class CancelOrderResponse(BaseRequest):
     """
-    取消待支付订单返回
+    取消待支付订单返回-响应
 
     :type ok: string
     :param ok: 
     """
     def __init__(
         self,
-        ok=None
+        ok = None
+    ):
+        super().__init__()
+        self.ok = ok
+
+
+class RetryOrderRequest(BaseRequest):
+    """
+    重试挂起状态订单请求-请求
+
+    :type dealer_id: string
+    :param dealer_id: 平台企业 ID
+
+    :type order_id: string
+    :param order_id: 平台企业订单号
+
+    :type ref: string
+    :param ref: 综合服务平台流水号
+
+    :type channel: string
+    :param channel: 支付路径名
+    """
+    def __init__(
+        self,
+        dealer_id = None,
+        order_id = None,
+        ref = None,
+        channel = None
+    ):
+        super().__init__()
+        self.dealer_id = dealer_id
+        self.order_id = order_id
+        self.ref = ref
+        self.channel = channel
+
+
+class RetryOrderResponse(BaseRequest):
+    """
+    重试挂起状态订单返回-响应
+
+    :type ok: string
+    :param ok: 请求标识
+    """
+    def __init__(
+        self,
+        ok = None
     ):
         super().__init__()
         self.ok = ok
@@ -575,14 +645,14 @@ class CancelOrderResponse(BaseRequest):
 
 class ListAccountRequest(BaseRequest):
     """
-    查询平台企业余额请求
+    查询平台企业余额请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
     """
     def __init__(
         self,
-        dealer_id=None
+        dealer_id = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -590,14 +660,14 @@ class ListAccountRequest(BaseRequest):
 
 class ListAccountResponse(BaseRequest):
     """
-    查询平台企业余额返回
+    查询平台企业余额返回-响应
 
     :type dealer_infos: list
     :param dealer_infos: 
     """
     def __init__(
         self,
-        dealer_infos=None
+        dealer_infos = None
     ):
         super().__init__()
         self.dealer_infos = dealer_infos
@@ -605,7 +675,7 @@ class ListAccountResponse(BaseRequest):
 
 class AccountInfo(BaseRequest):
     """
-    账户信息
+    账户信息-响应
 
     :type broker_id: string
     :param broker_id: 综合服务主体 ID
@@ -639,16 +709,16 @@ class AccountInfo(BaseRequest):
     """
     def __init__(
         self,
-        broker_id=None,
-        bank_card_balance=None,
-        is_bank_card=None,
-        alipay_balance=None,
-        is_alipay=None,
-        wxpay_balance=None,
-        is_wxpay=None,
-        rebate_fee_balance=None,
-        acct_balance=None,
-        total_balance=None
+        broker_id = None,
+        bank_card_balance = None,
+        is_bank_card = None,
+        alipay_balance = None,
+        is_alipay = None,
+        wxpay_balance = None,
+        is_wxpay = None,
+        rebate_fee_balance = None,
+        acct_balance = None,
+        total_balance = None
     ):
         super().__init__()
         self.broker_id = broker_id
@@ -665,7 +735,7 @@ class AccountInfo(BaseRequest):
 
 class GetEleReceiptFileRequest(BaseRequest):
     """
-    查询电子回单请求
+    查询电子回单请求-请求
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -675,8 +745,8 @@ class GetEleReceiptFileRequest(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        ref=None
+        order_id = None,
+        ref = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -685,7 +755,7 @@ class GetEleReceiptFileRequest(BaseRequest):
 
 class GetEleReceiptFileResponse(BaseRequest):
     """
-    查询电子回单返回
+    查询电子回单返回-响应
 
     :type expire_time: string
     :param expire_time: 链接失效时间
@@ -698,9 +768,9 @@ class GetEleReceiptFileResponse(BaseRequest):
     """
     def __init__(
         self,
-        expire_time=None,
-        file_name=None,
-        url=None
+        expire_time = None,
+        file_name = None,
+        url = None
     ):
         super().__init__()
         self.expire_time = expire_time
@@ -710,7 +780,7 @@ class GetEleReceiptFileResponse(BaseRequest):
 
 class NotifyOrderRequest(BaseRequest):
     """
-    订单支付状态回调通知
+    订单支付状态回调通知-请求
 
     :type notify_id: string
     :param notify_id: 通知 ID
@@ -723,9 +793,9 @@ class NotifyOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        notify_id=None,
-        notify_time=None,
-        data=None
+        notify_id = None,
+        notify_time = None,
+        data = None
     ):
         super().__init__()
         self.notify_id = notify_id
@@ -735,7 +805,7 @@ class NotifyOrderRequest(BaseRequest):
 
 class NotifyOrderData(BaseRequest):
     """
-    订单支付状态回调通知数据
+    订单支付状态回调通知数据-响应
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -773,6 +843,9 @@ class NotifyOrderData(BaseRequest):
     :type status_detail_message: string
     :param status_detail_message: 订单详细状态码描述
 
+    :type supplemental_detail_message: string
+    :param supplemental_detail_message: 订单状态补充信息
+
     :type broker_amount: string
     :param broker_amount: 综合服务主体支付金额
 
@@ -792,20 +865,32 @@ class NotifyOrderData(BaseRequest):
     :param finished_time: 订单完成时间，精确到秒
 
     :type broker_fee: string
-    :param broker_fee: 综合服务主体加成服务费
+    :param broker_fee: 应收综合服务主体加成服务费金额
 
     :type broker_real_fee: string
-    :param broker_real_fee: 余额账户支出加成服务费
+    :param broker_real_fee: 应收余额账户支出加成服务费金额
 
     :type broker_deduct_fee: string
-    :param broker_deduct_fee: 抵扣账户支出加成服务费
+    :param broker_deduct_fee: 应收加成服务费抵扣金额
+
+    :type user_fee: string
+    :param user_fee: 应收用户加成服务费金额
+
+    :type received_broker_fee: string
+    :param received_broker_fee: 实收综合服务主体加成服务费金额
+
+    :type received_broker_real_fee: string
+    :param received_broker_real_fee: 实收余额账户支出加成服务费金额
+
+    :type received_broker_deduct_fee: string
+    :param received_broker_deduct_fee: 实收加成服务费抵扣金额
+
+    :type received_user_fee: string
+    :param received_user_fee: 实收用户加成服务费金额
 
     :type pay_remark: string
     :param pay_remark: 订单备注
 
-    :type user_fee: string
-    :param user_fee: 用户加成服务费
-
     :type bank_name: string
     :param bank_name: 银行名称
 
@@ -817,32 +902,37 @@ class NotifyOrderData(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        pay=None,
-        broker_id=None,
-        dealer_id=None,
-        real_name=None,
-        card_no=None,
-        id_card=None,
-        phone_no=None,
-        status=None,
-        status_detail=None,
-        status_message=None,
-        status_detail_message=None,
-        broker_amount=None,
-        ref=None,
-        broker_bank_bill=None,
-        withdraw_platform=None,
-        created_at=None,
-        finished_time=None,
-        broker_fee=None,
-        broker_real_fee=None,
-        broker_deduct_fee=None,
-        pay_remark=None,
-        user_fee=None,
-        bank_name=None,
-        project_id=None,
-        user_id=None
+        order_id = None,
+        pay = None,
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        card_no = None,
+        id_card = None,
+        phone_no = None,
+        status = None,
+        status_detail = None,
+        status_message = None,
+        status_detail_message = None,
+        supplemental_detail_message = None,
+        broker_amount = None,
+        ref = None,
+        broker_bank_bill = None,
+        withdraw_platform = None,
+        created_at = None,
+        finished_time = None,
+        broker_fee = None,
+        broker_real_fee = None,
+        broker_deduct_fee = None,
+        user_fee = None,
+        received_broker_fee = None,
+        received_broker_real_fee = None,
+        received_broker_deduct_fee = None,
+        received_user_fee = None,
+        pay_remark = None,
+        bank_name = None,
+        project_id = None,
+        user_id = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -857,6 +947,7 @@ class NotifyOrderData(BaseRequest):
         self.status_detail = status_detail
         self.status_message = status_message
         self.status_detail_message = status_detail_message
+        self.supplemental_detail_message = supplemental_detail_message
         self.broker_amount = broker_amount
         self.ref = ref
         self.broker_bank_bill = broker_bank_bill
@@ -866,8 +957,12 @@ class NotifyOrderData(BaseRequest):
         self.broker_fee = broker_fee
         self.broker_real_fee = broker_real_fee
         self.broker_deduct_fee = broker_deduct_fee
-        self.pay_remark = pay_remark
         self.user_fee = user_fee
+        self.received_broker_fee = received_broker_fee
+        self.received_broker_real_fee = received_broker_real_fee
+        self.received_broker_deduct_fee = received_broker_deduct_fee
+        self.received_user_fee = received_user_fee
+        self.pay_remark = pay_remark
         self.bank_name = bank_name
         self.project_id = project_id
         self.user_id = user_id
@@ -875,7 +970,7 @@ class NotifyOrderData(BaseRequest):
 
 class CreateBatchOrderRequest(BaseRequest):
     """
-    批量下单请求
+    批次下单请求-请求
 
     :type batch_id: string
     :param batch_id: 平台企业批次号
@@ -898,19 +993,23 @@ class CreateBatchOrderRequest(BaseRequest):
     :type total_count: string
     :param total_count: 总笔数
 
+    :type mode: string
+    :param mode: 支付模式
+
     :type order_list: list
     :param order_list: 订单列表
     """
     def __init__(
         self,
-        batch_id=None,
-        dealer_id=None,
-        broker_id=None,
-        channel=None,
-        wx_app_id=None,
-        total_pay=None,
-        total_count=None,
-        order_list=None
+        batch_id = None,
+        dealer_id = None,
+        broker_id = None,
+        channel = None,
+        wx_app_id = None,
+        total_pay = None,
+        total_count = None,
+        mode = None,
+        order_list = None
     ):
         super().__init__()
         self.batch_id = batch_id
@@ -920,12 +1019,13 @@ class CreateBatchOrderRequest(BaseRequest):
         self.wx_app_id = wx_app_id
         self.total_pay = total_pay
         self.total_count = total_count
+        self.mode = mode
         self.order_list = order_list
 
 
 class BatchOrderInfo(BaseRequest):
     """
-    批量下单订单信息
+    批次下单订单信息-响应
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -959,16 +1059,16 @@ class BatchOrderInfo(BaseRequest):
     """
     def __init__(
         self,
-        order_id=None,
-        real_name=None,
-        id_card=None,
-        card_no=None,
-        openid=None,
-        phone_no=None,
-        project_id=None,
-        pay=None,
-        pay_remark=None,
-        notify_url=None
+        order_id = None,
+        real_name = None,
+        id_card = None,
+        card_no = None,
+        openid = None,
+        phone_no = None,
+        project_id = None,
+        pay = None,
+        pay_remark = None,
+        notify_url = None
     ):
         super().__init__()
         self.order_id = order_id
@@ -985,7 +1085,7 @@ class BatchOrderInfo(BaseRequest):
 
 class CreateBatchOrderResponse(BaseRequest):
     """
-    批量下单返回
+    批次下单返回-响应
 
     :type batch_id: string
     :param batch_id: 平台企业批次号
@@ -995,8 +1095,8 @@ class CreateBatchOrderResponse(BaseRequest):
     """
     def __init__(
         self,
-        batch_id=None,
-        result_list=None
+        batch_id = None,
+        result_list = None
     ):
         super().__init__()
         self.batch_id = batch_id
@@ -1005,7 +1105,7 @@ class CreateBatchOrderResponse(BaseRequest):
 
 class BatchOrderResult(BaseRequest):
     """
-    批量下单返回订单信息
+    批次下单返回订单信息-响应
 
     :type order_id: string
     :param order_id: 平台企业订单号
@@ -1015,22 +1115,52 @@ class BatchOrderResult(BaseRequest):
 
     :type pay: string
     :param pay: 订单金额
+
+    :type status: string
+    :param status: 下单状态
+
+    :type error_reasons: list
+    :param error_reasons: 下单失败原因
     """
     def __init__(
         self,
-        order_id=None,
-        ref=None,
-        pay=None
+        order_id = None,
+        ref = None,
+        pay = None,
+        status = None,
+        error_reasons = None
     ):
         super().__init__()
         self.order_id = order_id
         self.ref = ref
         self.pay = pay
+        self.status = status
+        self.error_reasons = error_reasons
+
+
+class BatchOrderErrorReasons(BaseRequest):
+    """
+    下单失败原因信息-响应
+
+    :type error_code: string
+    :param error_code: 不允许下单原因码
+
+    :type error_message: string
+    :param error_message: 不允许下单原因描述
+    """
+    def __init__(
+        self,
+        error_code = None,
+        error_message = None
+    ):
+        super().__init__()
+        self.error_code = error_code
+        self.error_message = error_message
 
 
 class ConfirmBatchOrderRequest(BaseRequest):
     """
-    批次确认请求
+    批次确认请求-请求
 
     :type batch_id: string
     :param batch_id: 平台企业批次号
@@ -1046,10 +1176,10 @@ class ConfirmBatchOrderRequest(BaseRequest):
     """
     def __init__(
         self,
-        batch_id=None,
-        dealer_id=None,
-        broker_id=None,
-        channel=None
+        batch_id = None,
+        dealer_id = None,
+        broker_id = None,
+        channel = None
     ):
         super().__init__()
         self.batch_id = batch_id
@@ -1060,5 +1190,326 @@ class ConfirmBatchOrderRequest(BaseRequest):
 
 class ConfirmBatchOrderResponse(BaseRequest):
     """
-    批次确认响应
+    批次确认返回-响应
     """
+
+
+class QueryBatchOrderRequest(BaseRequest):
+    """
+    查询批次订单信息请求-请求
+
+    :type batch_id: string
+    :param batch_id: 平台企业批次号
+
+    :type dealer_id: string
+    :param dealer_id: 平台企业 ID
+    """
+    def __init__(
+        self,
+        batch_id = None,
+        dealer_id = None
+    ):
+        super().__init__()
+        self.batch_id = batch_id
+        self.dealer_id = dealer_id
+
+
+class QueryBatchOrderResponse(BaseRequest):
+    """
+    查询批次订单信息返回-响应
+
+    :type broker_id: string
+    :param broker_id: 综合服务主体 ID
+
+    :type dealer_id: string
+    :param dealer_id: 平台企业 ID
+
+    :type batch_id: string
+    :param batch_id: 平台企业批次号
+
+    :type total_count: string
+    :param total_count: 总笔数
+
+    :type total_pay: string
+    :param total_pay: 订单总金额
+
+    :type channel: string
+    :param channel: 支付路径
+
+    :type batch_status: string
+    :param batch_status: 批次状态码
+
+    :type batch_status_message: string
+    :param batch_status_message: 批次状态码描述
+
+    :type batch_received_time: string
+    :param batch_received_time: 批次接收时间
+
+    :type order_list: list
+    :param order_list: 批次订单列表
+    """
+    def __init__(
+        self,
+        broker_id = None,
+        dealer_id = None,
+        batch_id = None,
+        total_count = None,
+        total_pay = None,
+        channel = None,
+        batch_status = None,
+        batch_status_message = None,
+        batch_received_time = None,
+        order_list = None
+    ):
+        super().__init__()
+        self.broker_id = broker_id
+        self.dealer_id = dealer_id
+        self.batch_id = batch_id
+        self.total_count = total_count
+        self.total_pay = total_pay
+        self.channel = channel
+        self.batch_status = batch_status
+        self.batch_status_message = batch_status_message
+        self.batch_received_time = batch_received_time
+        self.order_list = order_list
+
+
+class QueryBatchOrderInfo(BaseRequest):
+    """
+    查询批次订单信息订单详情-响应
+
+    :type order_id: string
+    :param order_id: 平台企业订单号
+
+    :type pay: string
+    :param pay: 订单金额
+
+    :type broker_id: string
+    :param broker_id: 综合服务主体 ID
+
+    :type dealer_id: string
+    :param dealer_id: 平台企业 ID
+
+    :type real_name: string
+    :param real_name: 姓名
+
+    :type card_no: string
+    :param card_no: 收款人账号
+
+    :type id_card: string
+    :param id_card: 身份证号码
+
+    :type phone_no: string
+    :param phone_no: 手机号
+
+    :type status: string
+    :param status: 订单状态码
+
+    :type status_detail: string
+    :param status_detail: 订单详情状态码
+
+    :type status_message: string
+    :param status_message: 订单状态码描述
+
+    :type status_detail_message: string
+    :param status_detail_message: 订单详情状态码描述
+
+    :type supplemental_detail_message: string
+    :param supplemental_detail_message: 订单状态补充信息
+
+    :type broker_amount: string
+    :param broker_amount: 综合服务主体支付金额
+
+    :type ref: string
+    :param ref: 综合服务平台流水号
+
+    :type broker_bank_bill: string
+    :param broker_bank_bill: 支付交易流水号
+
+    :type withdraw_platform: string
+    :param withdraw_platform: 支付路径
+
+    :type created_at: string
+    :param created_at: 订单接收时间
+
+    :type finished_time: string
+    :param finished_time: 订单完成时间
+
+    :type broker_fee: string
+    :param broker_fee: 应收综合服务主体加成服务费金额
+
+    :type broker_real_fee: string
+    :param broker_real_fee: 应收余额账户支出加成服务费金额
+
+    :type broker_deduct_fee: string
+    :param broker_deduct_fee: 应收加成服务费抵扣金额
+
+    :type user_fee: string
+    :param user_fee: 应收用户加成服务费金额
+
+    :type received_broker_fee: string
+    :param received_broker_fee: 实收综合服务主体加成服务费金额
+
+    :type received_broker_real_fee: string
+    :param received_broker_real_fee: 实收余额账户支出加成服务费金额
+
+    :type received_broker_deduct_fee: string
+    :param received_broker_deduct_fee: 实收加成服务费抵扣金额
+
+    :type received_user_fee: string
+    :param received_user_fee: 实收用户加成服务费金额
+
+    :type pay_remark: string
+    :param pay_remark: 订单备注
+
+    :type bank_name: string
+    :param bank_name: 银行名称
+
+    :type project_id: string
+    :param project_id: 业务线标识
+    """
+    def __init__(
+        self,
+        order_id = None,
+        pay = None,
+        broker_id = None,
+        dealer_id = None,
+        real_name = None,
+        card_no = None,
+        id_card = None,
+        phone_no = None,
+        status = None,
+        status_detail = None,
+        status_message = None,
+        status_detail_message = None,
+        supplemental_detail_message = None,
+        broker_amount = None,
+        ref = None,
+        broker_bank_bill = None,
+        withdraw_platform = None,
+        created_at = None,
+        finished_time = None,
+        broker_fee = None,
+        broker_real_fee = None,
+        broker_deduct_fee = None,
+        user_fee = None,
+        received_broker_fee = None,
+        received_broker_real_fee = None,
+        received_broker_deduct_fee = None,
+        received_user_fee = None,
+        pay_remark = None,
+        bank_name = None,
+        project_id = None
+    ):
+        super().__init__()
+        self.order_id = order_id
+        self.pay = pay
+        self.broker_id = broker_id
+        self.dealer_id = dealer_id
+        self.real_name = real_name
+        self.card_no = card_no
+        self.id_card = id_card
+        self.phone_no = phone_no
+        self.status = status
+        self.status_detail = status_detail
+        self.status_message = status_message
+        self.status_detail_message = status_detail_message
+        self.supplemental_detail_message = supplemental_detail_message
+        self.broker_amount = broker_amount
+        self.ref = ref
+        self.broker_bank_bill = broker_bank_bill
+        self.withdraw_platform = withdraw_platform
+        self.created_at = created_at
+        self.finished_time = finished_time
+        self.broker_fee = broker_fee
+        self.broker_real_fee = broker_real_fee
+        self.broker_deduct_fee = broker_deduct_fee
+        self.user_fee = user_fee
+        self.received_broker_fee = received_broker_fee
+        self.received_broker_real_fee = received_broker_real_fee
+        self.received_broker_deduct_fee = received_broker_deduct_fee
+        self.received_user_fee = received_user_fee
+        self.pay_remark = pay_remark
+        self.bank_name = bank_name
+        self.project_id = project_id
+
+
+class CancelBatchOrderRequest(BaseRequest):
+    """
+    批次撤销请求-请求
+
+    :type batch_id: string
+    :param batch_id: 平台企业批次号
+
+    :type dealer_id: string
+    :param dealer_id: 平台企业 ID
+
+    :type broker_id: string
+    :param broker_id: 综合服务主体 ID
+    """
+    def __init__(
+        self,
+        batch_id = None,
+        dealer_id = None,
+        broker_id = None
+    ):
+        super().__init__()
+        self.batch_id = batch_id
+        self.dealer_id = dealer_id
+        self.broker_id = broker_id
+
+
+class CancelBatchOrderResponse(BaseRequest):
+    """
+    批次撤销返回-响应
+    """
+
+
+class CheckUserAmountRequest(BaseRequest):
+    """
+    用户结算金额校验请求-请求
+
+    :type broker_id: string
+    :param broker_id: 综合服务主体 ID
+
+    :type real_name: string
+    :param real_name: 姓名
+
+    :type id_card: string
+    :param id_card: 身份证号码
+
+    :type amount: string
+    :param amount: 校验金额
+    """
+    def __init__(
+        self,
+        broker_id = None,
+        real_name = None,
+        id_card = None,
+        amount = None
+    ):
+        super().__init__()
+        self.broker_id = broker_id
+        self.real_name = real_name
+        self.id_card = id_card
+        self.amount = amount
+
+
+class CheckUserAmountResponse(BaseRequest):
+    """
+    用户结算金额校验返回-响应
+
+    :type is_over_whole_user_month_quota: bool
+    :param is_over_whole_user_month_quota: 是否超过月限额
+
+    :type is_over_whole_user_year_quota: bool
+    :param is_over_whole_user_year_quota: 是否超过年限额
+    """
+    def __init__(
+        self,
+        is_over_whole_user_month_quota = None,
+        is_over_whole_user_year_quota = None
+    ):
+        super().__init__()
+        self.is_over_whole_user_month_quota = is_over_whole_user_month_quota
+        self.is_over_whole_user_year_quota = is_over_whole_user_year_quota
