@@ -1,11 +1,11 @@
-"""个人所得税扣缴明细表"""
+"""个人所得税申报明细表"""
 
 from ...base import BaseRequest
 
 
 class GetTaxFileRequest(BaseRequest):
     """
-    下载个人所得税扣缴明细表请求
+    下载个人所得税申报明细表请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -18,9 +18,9 @@ class GetTaxFileRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        ent_id=None,
-        year_month=None
+        dealer_id = None,
+        ent_id = None,
+        year_month = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -30,14 +30,14 @@ class GetTaxFileRequest(BaseRequest):
 
 class GetTaxFileResponse(BaseRequest):
     """
-    下载个人所得税扣缴明细表返回
+    下载个人所得税申报明细表返回-响应
 
     :type file_info: list
     :param file_info: 文件详情
     """
     def __init__(
         self,
-        file_info=None
+        file_info = None
     ):
         super().__init__()
         self.file_info = file_info
@@ -45,7 +45,7 @@ class GetTaxFileResponse(BaseRequest):
 
 class FileInfo(BaseRequest):
     """
-    报税文件详情
+    报税文件详情-响应
 
     :type name: string
     :param name: 文件名称
@@ -58,9 +58,9 @@ class FileInfo(BaseRequest):
     """
     def __init__(
         self,
-        name=None,
-        url=None,
-        pwd=None
+        name = None,
+        url = None,
+        pwd = None
     ):
         super().__init__()
         self.name = name
@@ -70,7 +70,7 @@ class FileInfo(BaseRequest):
 
 class GetUserCrossRequest(BaseRequest):
     """
-    查询纳税人是否为跨集团用户请求
+    查询纳税人是否为跨集团用户请求-请求
 
     :type dealer_id: string
     :param dealer_id: 平台企业 ID
@@ -86,10 +86,10 @@ class GetUserCrossRequest(BaseRequest):
     """
     def __init__(
         self,
-        dealer_id=None,
-        year=None,
-        id_card=None,
-        ent_id=None
+        dealer_id = None,
+        year = None,
+        id_card = None,
+        ent_id = None
     ):
         super().__init__()
         self.dealer_id = dealer_id
@@ -100,14 +100,14 @@ class GetUserCrossRequest(BaseRequest):
 
 class GetUserCrossResponse(BaseRequest):
     """
-    查询纳税人是否为跨集团用户返回
+    查询纳税人是否为跨集团用户返回-响应
 
     :type is_cross: bool
     :param is_cross: 跨集团标识
     """
     def __init__(
         self,
-        is_cross=None
+        is_cross = None
     ):
         super().__init__()
         self.is_cross = is_cross
