@@ -6,6 +6,8 @@ from ...utils import Utils
 
 
 class PaymentClient(BaseClient):
+    """实时支付客户端"""
+
     def __init__(self, config):
         super().__init__(config)
 
@@ -121,6 +123,20 @@ class PaymentClient(BaseClient):
             Utils.copy_dict(request.__dict__)
         )
 
+    def retry_order(self, request: RetryOrderRequest):
+        """ 重试挂起状态订单
+
+        :type request: RetryOrderRequest
+        :param request: the RetryOrderRequest request parameters class.
+
+        :return: RetryOrderResponse
+        """
+        return self._post(
+            "/api/payment/v1/order/retry",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
+
     def create_batch_order(self, request: CreateBatchOrderRequest):
         """ 批次下单
 
@@ -148,3 +164,45 @@ class PaymentClient(BaseClient):
             request.request_id,
             Utils.copy_dict(request.__dict__)
         )
+
+    def query_batch_order(self, request: QueryBatchOrderRequest):
+        """ 查询批次订单信息
+
+        :type request: QueryBatchOrderRequest
+        :param request: the QueryBatchOrderRequest request parameters class.
+
+        :return: QueryBatchOrderResponse
+        """
+        return self._get(
+            "/api/payment/v1/query-batch",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
+
+    def cancel_batch_order(self, request: CancelBatchOrderRequest):
+        """ 批次撤销
+
+        :type request: CancelBatchOrderRequest
+        :param request: the CancelBatchOrderRequest request parameters class.
+
+        :return: CancelBatchOrderResponse
+        """
+        return self._post(
+            "/api/payment/v1/cancel-batch",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
+
+    def check_user_amount(self, request: CheckUserAmountRequest):
+        """ 用户结算金额校验
+
+        :type request: CheckUserAmountRequest
+        :param request: the CheckUserAmountRequest request parameters class.
+
+        :return: CheckUserAmountResponse
+        """
+        return self._post(
+            "/api/payment/v1/risk-check/amount",
+            request.request_id,
+            Utils.copy_dict(request.__dict__)
+        )
