@@ -1,6 +1,5 @@
 import platform
 import uuid
-
 import requests
 
 from .. import __version__
@@ -8,67 +7,63 @@ from ..message import *
 
 
 class BaseClient(object):
-    def __init__(self, config, timeout=30):
+    def __init__(self, config):
         """
         :type config: Config
         :param config: 配置信息
 
-        :type timeout: int
-        :param timeout: 请求超时时间。非必填，默认 30 秒
         """
 
-        encrypt_type = config.sign_type
-        if encrypt_type not in("sha256", "rsa"):
-            raise ValueError('sign_type error! signType must be rsa or sha256!')
+        sign_type = config.sign_type
 
         self.__des3key = config.des3key
+        self.__app_key = config.app_key
+
         self.__encrypt = None
-        if encrypt_type == "sha256":
-            self.__encrypt = Des3EncryptAndHmacSign (
-                config.app_key, config.des3key)
-        if encrypt_type == "rsa":
-            self.__encrypt = Des3EncryptAndRSASign(
-                config.app_key, config.yzh_public_key, config.dealer_private_key, config.des3key)
+        if sign_type == "sha256":
+            self.__encrypt = HmacSigner(config.app_key)
+        if sign_type == "rsa":
+            self.__encrypt = RSASigner(config.app_key, config.yzh_public_key, config.dealer_private_key)
 
         self.__dealer_id = config.dealer_id
         self.__base_url = config.host
-        self.__timeout = timeout
+        self.__timeout = config.timeout
 
     def __header(self, request_id):
         if type(request_id) is not str or request_id == "":
             request_id = str(int(time.time()))
         return {
-            'dealer-id': self.__dealer_id,
-            'request-id': request_id,
+            "dealer-id": self.__dealer_id,
+            "request-id": request_id,
             "Content-Type": "application/x-www-form-urlencoded",
-            "User-Agent": "yunzhanghu-sdk-python/%s/%s/%s" % (
-                __version__, platform.platform(), platform.python_version()),
+            "User-Agent": "yunzhanghu-sdk-python/%s/%s" % (
+                __version__, platform.python_version()),
         }
 
     def __request(self, method, url, **kwargs):
-        data = kwargs['data'] if 'data' in kwargs else None
-        param = kwargs['param'] if 'param' in kwargs else None
-        headers = self.__header(kwargs['request_id'])
+        data = kwargs.get("data", None)
+        param = kwargs.get("param", None)
+        headers = self.__header(kwargs["request_id"])
         return self.__handle_resp(
             data, param, headers,
             requests.request(method=method,
                              url=self.__base_url + url,
                              headers=headers,
-                             data=ReqMessage(self.__encrypt, data).pack(),
-                             params=ReqMessage(self.__encrypt, param).pack(),
+                             data=ReqMessage(self.__encrypt, data, self.__des3key).pack(),
+                             params=ReqMessage(self.__encrypt, param, self.__des3key).pack(),
                              timeout=self.__timeout))
 
     def _post(self, url, request_id, data):
-        kwargs = {'data': data, 'request_id': request_id}
-        return self.__request(method='POST', url=url, **kwargs)
+        kwargs = {"data": data, "request_id": request_id}
+        return self.__request(method="POST", url=url, **kwargs)
 
     def _get(self, url, request_id, param):
-        kwargs = {'param': param, 'request_id': request_id}
-        return self.__request(method='GET', url=url, **kwargs)
+        kwargs = {"param": param, "request_id": request_id}
+        return self.__request(method="GET", url=url, **kwargs)
 
     def __handle_resp(self, req_data, req_param, headers, resp):
         if resp is None:
-            raise ValueError('resp is None')
+            raise ValueError("resp is None")
 
         resp.raise_for_status()
         return RespMessage(self.__des3key, resp.text, req_data,
@@ -97,3 +92,8 @@ class BaseRequest(object):
         :param request_id: 请求 ID
         """
         self.__request_id = request_id
+
+    def __str__(self):
+        res = self.__dict__.copy()
+        del res["_BaseRequest__request_id"]
+        return f"{self.__class__.__name__}({', '.join(f'{key}={getattr(self, key)}' for key in res.keys())})"
